@@ -6,7 +6,7 @@ import tensorflow as tf
 
 class TimeSeriesInterpretorRNN:
 
-  def __init__(self,model,background,test,max_output,features,max_display,decision_range,Measure):
+  def __init__(self,model,background,test,max_output,features,max_display,decision_range,Measure,dependence_feature_3):
     self.model = model
     self.background = background
     self.test = test
